==> crepobenchmark-0.0.2.tar.gz: crepobenchmark-0.0.2/crepobenchmark/utils.py <==
import subprocess
import tempfile
from pathlib import Path




def singleton(class_):
    """ wrapper that allows to define a singleton class """

    class class_w(class_):
        _instance = None

        def __new__(class_, *args, **kwargs):
            if class_w._instance is None:
                class_w._instance = super(class_w,
                                          class_).__new__(class_,
                                                          *args,
                                                          **kwargs)
                class_w._instance._sealed = False
            return class_w._instance

        def __init__(self, *args, **kwargs):
            if self._sealed:
                return
            super(class_w, self).__init__(*args, **kwargs)
            self._sealed = True

    class_w.__name__ = class_.__name__
    return class_w



def gen_exec(cmd, check_return: bool = False):
    popen = subprocess.Popen(cmd, stdout=subprocess.PIPE, universal_newlines=True)
    for stdout_line in iter(popen.stdout.readline, ""):
        yield stdout_line
    popen.stdout.close()
    return_code = popen.wait()
    if return_code and check_return:
        raise subprocess.CalledProcessError(return_code, cmd)


def exec_bash(cmd: str, check_return: bool = False):
    return [s for s in gen_exec(cmd.split(), check_return)]


def exec_bash_print(cmd: str, check_return: bool = False):
    for path in gen_exec(cmd.split(), check_return):
        print(path, end="")


def gettempdir():
    return tempfile.gettempdir()


def write_file(path, content, binary:bool = False):
    flags = "wb+" if binary else "w+"
    with open(Path(path).absolute(), flags) as f:
        f.write(content)

==> crepobenchmark-0.0.4.tar.gz: crepobenchmark-0.0.4/crepobenchmark/utils.py <==
import subprocess
import tempfile
from pathlib import Path




def singleton(class_):
    """ wrapper that allows to define a singleton class """

    class class_w(class_):
        _instance = None

        def __new__(class_, *args, **kwargs):
            if class_w._instance is None:
                class_w._instance = super(class_w,
                                          class_).__new__(class_,
                                                          *args,
                                                          **kwargs)
                class_w._instance._sealed = False
            return class_w._instance

        def __init__(self, *args, **kwargs):
            if self._sealed:
                return
            super(class_w, self).__init__(*args, **kwargs)
            self._sealed = True

    class_w.__name__ = class_.__name__
    return class_w



def gen_exec(cmd, check_return: bool = False, parse_error = False):

    args = dict(stdout=subprocess.PIPE, universal_newlines=True)

    if parse_error:
      args["stderr"] = subprocess.PIPE

    popen = subprocess.Popen(cmd, **args)
    for stdout_line in iter(popen.stdout.readline, ""):
        yield stdout_line

    if parse_error:
        for stderr_line in iter(popen.stderr.readline, ""):
            yield stderr_line

    popen.stdout.close()
    return_code = popen.wait()
    if return_code and check_return:
        raise subprocess.CalledProcessError(return_code, cmd)


def exec_bash(cmd: str, check_return: bool = False, parse_error : bool = False):
    return [s for s in gen_exec(cmd.split(), check_return, parse_error)]


def exec_bash_print(cmd: str, check_return: bool = False):
    for path in gen_exec(cmd.split(), check_return):
        print(path, end="")


def gettempdir():
    return tempfile.gettempdir()


def write_file(path, content, binary:bool = False):
    flags = "wb+" if binary else "w+"
    with open(Path(path).absolute(), flags) as f:
        f.write(content)
